Developers guide — linkml documentation

# Developers guide

Contents:

- GitHub Organization
- Jupyter Notebooks
  - LinkML Notebooks
  - linkml-runtime Notebooks
- Manipulating Schemas
- Tool Implementor Guide
  - General Considerations
  - Schema Conformance Levels
  - Other Languages
  - General Guidelines for applications
  - Customizing and application hints
  - Using other frameworks
- Contributing Code
  - Setup and Installation
  - Pull Requests
  - Tests